@@ -30,12 +30,10 @@ warnings.simplefilter("ignore")
 
 requests.packages.urllib3.disable_warnings(category=InsecureRequestWarning)
 
-logging.basicConfig(format=' %(message)s')
+logging.basicConfig(format='%(asctime)s : %(message)s', filename='dyagram.log')
 
 
-
-
-class dyagram:
+class Dyagram:
 
     def __init__(self, inventory_file=None, verbose=False):
 
@@ -1101,7 +1099,7 @@ def main():
             dyinit.dy_init()
 
         if args.dyagram_args[0].lower() == "discover":
-            dy = dyagram(verbose=args.verbose)
+            dy = Dyagram(verbose=args.verbose)
             dy.discover()
 
         if args.dyagram_args[0].lower() == "export":
@@ -1126,7 +1124,7 @@ def main():
                     except:
                         print(f"Site {args.dyagram_args[2]} doesn't exist")
     except:
-        tb = dyagram.get_traceback()
+        tb = Dyagram.get_traceback()
         print(f"DEVICE: MAIN EXCEPTION : {tb}")
 
 
